﻿import flash.geom.ColorTransform;

/**
* The ColorTransformUtil class includes a collection of utilities
* that allows for more intuitive color manipulation.
* 
* @author Mark Walters
* © 2006 DigitalFlipbook
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* Based on work by Robert Penner for the Color class.
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 8
*/
class com.robertpenner.utils.ColorTransformUtil {
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	function ColorTransformUtil () {
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Specifies an RGB color for a ColorTransform object using a string hexadecimal value.
	* 
	* @param	colorTrans	The ColorTransform object to manipulate.
	* @param	hexStr		The string hexadecimal color to be set.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setRGBStr(my_colorTrans, "#FFFF00");
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setRGBStr (colorTrans:ColorTransform, hexStr:String):Void {
		hexStr = hexStr.substr(-6, 6);
		colorTrans.rgb = parseInt(hexStr, 16);
	}
	
	/**
	* Returns the R+G+B combination currently in use by the ColorTransform object as a string hexadecimal value.
	* 
	* @param	colorTrans	The ColorTransform object from which to retrieve the value.
	* @return	The string hexadecimal color.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.rgb = 0x0000FF;
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getRGBStr(my_colorTrans));
	* </code></pre>
	*/
	public static function getRGBStr (colorTrans:ColorTransform):String {
		var hexStr:String = colorTrans.rgb.toString(16);
		var toFill:Number = 6 - hexStr.length;
		while (toFill--) hexStr = "0" + hexStr;
		return hexStr.toUpperCase();
	}
	
	/**
	* Specifies an RGB color for a ColorTransform object using individual red, green, and blue values.
	* 
	* @param	colorTrans	The ColorTransform object to manipulate.
	* @param	r			The red color value.
	* @param	g			The green color value.
	* @param	b			The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setRGB2(my_colorTrans, 255, 0, 255);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setRGB2 (colorTrans:ColorTransform, r:Number, g:Number, b:Number):Void {
		colorTrans.rgb = (r << 16 | g << 8 | b);
	}
	
	/**
	* Returns the R+G+B values currently in use by the ColorTransform object as individual red, green, and blue values.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The RBG value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* var rgb:Object = ColorTransformUtil.getRGB2(my_colorTrans);
	* trace (rgb.r);
	* trace (rgb.g);
	* trace (rgb.b);
	* </code></pre>
	*/
	public static function getRGB2 (colorTrans:ColorTransform):Object {
		return {r:colorTrans.redOffset, g:colorTrans.greenOffset, b:colorTrans.blueOffset};
	}
	
	/**
	* Resets a ColorTransform object to its default values.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* my_colorTrans.rgb = 0x0000FF;
	* my_trans.colorTransform = my_colorTrans;
	* ColorTransformUtil.reset(my_colorTrans);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function reset (colorTrans:ColorTransform):Void {
		colorTrans.redMultiplier = 1;
		colorTrans.greenMultiplier = 1;
		colorTrans.blueMultiplier = 1;
		colorTrans.redOffset = 0;
		colorTrans.greenOffset = 0;
		colorTrans.blueOffset = 0;
	}
	
	/**
	* Specifies the brightness of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	bright	A percentage value between -100 and 100. Positive values brighten the color. and negative values darken it.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBrightness(my_colorTrans, -50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setBrightness (colorTrans:ColorTransform, bright:Number):Void {
		with (colorTrans) {
			redMultiplier = greenMultiplier = blueMultiplier = 1 - Math.abs(bright/100);
			redOffset = greenOffset = blueOffset = (bright/100 > 0) ? bright/100 * 256 : 0;
		}
	}
	
	/**
	* Returns the brightness of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The brightness value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBrightness(my_colorTrans, 50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getBrightness(my_colorTrans));
	* </code></pre>
	*/
	public static function getBrightness (colorTrans:ColorTransform):Number {
		with (colorTrans) return (redOffset)*100 ? (1 - redMultiplier)*100 : (redMultiplier - 1)*100;
	}
	
	/**
	* Pushes a ColorTransform object towards black or white by an absolute amount.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	offset	A number between -255 and 255. Positive values push colors towards white; negative values towards black.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBrightOffset(my_colorTrans, 140);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setBrightOffset (colorTrans:ColorTransform, offset:Number):Void {
		with (colorTrans) redOffset = greenOffset = blueOffset = offset;
	}
	
	/**
	* Returns the brightness offset value of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The brightness offset value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBrightOffset(my_colorTrans, 140);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getBrightOffset(my_colorTrans));
	* </code></pre>
	*/
	public static function getBrightOffset (colorTrans:ColorTransform):Number {
		return colorTrans.redOffset;
	}
	
	/**
	* Tints a ColorTransform object with a color according to a certain percentage.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTint(my_colorTrans, 0, 0, 128, 50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setTint (colorTrans:ColorTransform, r:Number, g:Number, b:Number, percent:Number):Void {
		var ratio:Number = percent/100;
		colorTrans.redOffset = r*ratio;
		colorTrans.greenOffset = g*ratio;
		colorTrans.blueOffset = b*ratio;
		colorTrans.redMultiplier = colorTrans.greenMultiplier = colorTrans.blueMultiplier = (100 - percent)/100;
	}
	
	/**
	* Returns the tint of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The tint value object with r, g, b, and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTint(my_colorTrans, 0, 0, 128, 50);
	* my_trans.colorTransform = my_colorTrans;
	* var tint:Object = ColorTransformUtil.getTint(my_colorTrans);
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* trace (tint.percent);
	* </code></pre>
	*/
	public static function getTint (colorTrans:ColorTransform):Object {
		var tint:Object = {percent: (1 - colorTrans.redMultiplier)*100};
		var ratio:Number = 100/tint.percent;
		tint.r = colorTrans.redOffset * ratio;
		tint.g = colorTrans.greenOffset * ratio;
		tint.b = colorTrans.blueOffset * ratio;
		return tint;
	}
	
	/**
	* Tints a ColorTransform object with a color according to a certain percentage.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	rgb		The rgb value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTint2(my_colorTrans, 0x0000FF, 100);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setTint2 (colorTrans:ColorTransform, rgb:Number, percent:Number):Void {
		var r:Number = (rgb >> 16);
		var g:Number = (rgb >> 8) & 0xFF;
		var b:Number = rgb & 0xFF;
		var ratio:Number = percent/100;
		colorTrans.redOffset = r*ratio;
		colorTrans.greenOffset = g*ratio;
		colorTrans.blueOffset = b*ratio;
		colorTrans.redMultiplier = colorTrans.greenMultiplier = colorTrans.blueMultiplier = (100 - percent)/100;
	}
	
	/**
	* Returns the tint of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The tint value object with rgb and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTint2(my_colorTrans, 0x0000FF, 100);
	* my_trans.colorTransform = my_colorTrans;
	* var tint:Object = ColorTransformUtil.getTint2(my_colorTrans);
	* trace (tint.rgb);
	* trace (tint.percent);
	* </code></pre>
	*/
	public static function getTint2 (colorTrans:ColorTransform):Object {
		var tint:Object = {percent: (1 - colorTrans.redMultiplier)*100};
		var ratio:Number = 100/tint.percent;
		tint.rgb = (colorTrans.redOffset*ratio)<<16 | (colorTrans.greenOffset*ratio)<<8 | colorTrans.blueOffset*ratio;
		return tint;
	}
	
	/**
	* Tints a ColorTransform object with a color according to red, green, and blue values.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTintOffset(my_colorTrans, 0, 0, 128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setTintOffset (colorTrans:ColorTransform, r:Number, g:Number, b:Number):Void {
		with (colorTrans) { redOffset=r; greenOffset=g; blueOffset=b; }
	}
	
	/**
	* Returns the tint offset of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The tint offset value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTintOffset(my_colorTrans, 0, 0, 128);
	* my_trans.colorTransform = my_colorTrans;
	* var tint:Object = ColorTransformUtil.getTintOffset(my_colorTrans);
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* </code></pre>
	*/
	public static function getTintOffset (colorTrans:ColorTransform):Object {
		return {r:colorTrans.redOffset, g:colorTrans.greenOffset, b:colorTrans.blueOffset};
	}
	
	/**
	* Tints a ColorTransform object with a color according to an rgb value.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	rgb		The rgb value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTintOffset2(my_colorTrans, 0x000080);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setTintOffset2 (colorTrans:ColorTransform, rgb:Number):Void {
		var r:Number = (rgb >> 16) ;
		var g:Number = (rgb >> 8) & 0xFF;
		var b:Number = rgb & 0xFF;
		with (colorTrans) { redOffset=r; greenOffset=g; blueOffset=b; }
	}
	
	/**
	* Returns the tint offset of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The tint offset value object with an rgb properties.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setTintOffset2(my_colorTrans, 0x000080);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getTintOffset2(my_colorTrans));
	* </code></pre>
	*/
	public static function getTintOffset2 (colorTrans:ColorTransform):Number {
		return (colorTrans.redOffset)<<16 | (colorTrans.greenOffset)<<8 | (colorTrans.blueOffset);
	}
	
	/**
	* Performs a straightforward color inversion.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.invert(my_colorTrans);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function invert (colorTrans:ColorTransform):Void {
		with (colorTrans) {
			redMultiplier = -redMultiplier;
			greenMultiplier = -greenMultiplier;
			blueMultiplier = -blueMultiplier;
			redOffset = 255 - redOffset;
			greenOffset = 255 - greenOffset;
			blueOffset = 255 - blueOffset;
		}
	}
	
	/**
	* Inverts a ColorTransform object by a certain percentage.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	percent	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setNegative(my_colorTrans, 60);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setNegative (colorTrans:ColorTransform, percent:Number):Void {
		colorTrans.redMultiplier = colorTrans.greenMultiplier = colorTrans.blueMultiplier = 100 - 2 * percent;
		colorTrans.redOffset = colorTrans.greenOffset = colorTrans.blueOffset = percent * (255/100);
	}
	
	/**
	* Returns the negative percentage of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setNegative(my_colorTrans, 60);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getNegative(my_colorTrans));
	* </code></pre>
	*/
	public static function getNegative (colorTrans:ColorTransform):Number {
		return colorTrans.redOffset * (100/255);
	}
	
	/**
	* Specifies a red color value for a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	amount	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setRed(my_colorTrans, 128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setRed (colorTrans:ColorTransform, amount:Number):Void {
		colorTrans.rgb = (amount << 16 | colorTrans.greenOffset << 8 | colorTrans.blueOffset);
	}
	
	/**
	* Returns the red color value of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setRed(my_colorTrans, 128);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getRed(my_colorTrans));
	* </code></pre>
	*/
	public static function getRed (colorTrans:ColorTransform):Number {
		return colorTrans.redOffset;
	}
	
	/**
	* Specifies a green color value for a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	amount	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setGreen(my_colorTrans, 128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setGreen (colorTrans:ColorTransform, amount:Number):Void {
		colorTrans.rgb = (colorTrans.redOffset << 16 | amount << 8 | colorTrans.blueOffset);
	}
	
	/**
	* Returns the green color value of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setGreen(my_colorTrans, 128);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getGreen(my_colorTrans));
	* </code></pre>
	*/
	public static function getGreen (colorTrans:ColorTransform):Number {
		return colorTrans.greenOffset;
	}
	
	/**
	* Specifies a blue color value for a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	amount	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBlue(my_colorTrans, 128);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setBlue (colorTrans:ColorTransform, amount:Number):Void {
		colorTrans.rgb = (colorTrans.redOffset << 16 | colorTrans.greenOffset << 8 | amount);
	}
	
	/**
	* Returns the blue color value of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBlue(my_colorTrans, 128);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getBlue(my_colorTrans));
	* </code></pre>
	*/
	public static function getBlue (colorTrans:ColorTransform):Number {
		return colorTrans.blueOffset;
	}
	
	/**
	* Specifies a red percentage value for a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	percent	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setRedPercent(my_colorTrans, 50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setRedPercent (colorTrans:ColorTransform, percent:Number):Void {
		colorTrans.redMultiplier = percent/100;
	}
	
	/**
	* Returns the red percentage value of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setRedPercent(my_colorTrans, 50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getRedPercent(my_colorTrans));
	* </code></pre>
	*/
	public static function getRedPercent (colorTrans:ColorTransform):Number {
		return colorTrans.redMultiplier*100;
	}
	
	/**
	* Specifies a green percentage value for a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	percent	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setGreenPercent(my_colorTrans, 50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setGreenPercent (colorTrans:ColorTransform, percent:Number):Void {
		colorTrans.greenMultiplier = percent/100;
	}
	
	/**
	* Returns the green percentage value of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setGreenPercent(my_colorTrans, 50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getGreenPercent(my_colorTrans));
	* </code></pre>
	*/
	public static function getGreenPercent (colorTrans:ColorTransform):Number {
		return colorTrans.greenMultiplier*100;
	}
	
	/**
	* Specifies a blue percentage value for a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object to manipulate.
	* @param	percent	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBluePercent(my_colorTrans, 50);
	* my_trans.colorTransform = my_colorTrans;
	* </code></pre>
	*/
	public static function setBluePercent (colorTrans:ColorTransform, percent:Number):Void {
		colorTrans.blueMultiplier = percent/100;
	}
	
	/**
	* Returns the blue percentage value of a ColorTransform object.
	* 
	* @param	colorTrans		The ColorTransform object from which to retrieve the value.
	* @return	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_colorTrans:ColorTransform = new ColorTransform();
	* var my_trans:Transform = new Transform(my_mc);
	* ColorTransformUtil.setBluePercent(my_colorTrans, 50);
	* my_trans.colorTransform = my_colorTrans;
	* trace (ColorTransformUtil.getBluePercent(my_colorTrans));
	* </code></pre>
	*/
	public static function getBluePercent (colorTrans:ColorTransform):Number {
		return colorTrans.blueMultiplier*100;
	}
	
}
