﻿/**
* The ColorUtil class includes a collection of utilities
* that allows for more intuitive color manipulation.
* 
* @author Robert Penner (AS 1.0)
* © 2002 Robert Penner
* http://www.robertpenner.com
* 
* @author Mark Walters (AS 2.0)
* © 2006 DigitalFlipbook
* © 2006 DigitalFlipbook
* http://www.digitalflipbook.com
* 
* @version	1.0
* 
* @since	ActionScript 2.0; Flash Player 6
*/
class com.robertpenner.utils.ColorUtil {
	
	/*
	* *********************************************************
	* CONSTRUCTOR
	* *********************************************************
	*
	*/
	function ColorUtil () {
	}
	
	
	/*
	* *********************************************************
	* PUBLIC METHODS
	* *********************************************************
	* 
	*/
	
	/**
	* Specifies an RGB color for a Color object using a string hexadecimal value.
	* 
	* @param	col		The Color object to manipulate.
	* @param	hexStr	The string hexadecimal color to be set.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRGBStr(my_color, "#FFFF00");
	* </code></pre>
	*/
	public static function setRGBStr (col:Color, hexStr:String):Void {
		hexStr = hexStr.substr(-6, 6);
		col.setRGB (parseInt(hexStr, 16));
	}
	
	/**
	* Returns the R+G+B combination currently in use by the Color object as a string hexadecimal value.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The string hexadecimal color.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* my_color.setRGB(0x0000FF);
	* trace (ColorUtil.getRGBStr(my_color));
	* </code></pre>
	*/
	public static function getRGBStr (col:Color):String {
		var hexStr:String = col.getRGB().toString(16);
		var toFill:Number = 6 - hexStr.length;
		while (toFill--) hexStr = "0" + hexStr;
		return hexStr.toUpperCase();
	}
	
	/**
	* Specifies an RGB color for a Color object using individual red, green, and blue values.
	* 
	* @param	col		The Color object to manipulate.
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRGB2(my_color, 255, 0, 255);
	* </code></pre>
	*/
	public static function setRGB2 (col:Color, r:Number, g:Number, b:Number):Void {
		col.setRGB(r << 16 | g << 8 | b);
	}
	
	/**
	* Returns the R+G+B values currently in use by the Color object as individual red, green, and blue values.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The RBG value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRGB2(my_color, 255, 0, 255);
	* var rgb:Object = ColorUtil.getRGB2(my_color);
	* trace (rgb.r);
	* trace (rgb.g);
	* trace (rgb.b);
	* </code></pre>
	*/
	public static function getRGB2 (col:Color):Object {
		var t:Object = col.getTransform();
		return {r:t.rb, g:t.gb, b:t.bb};
	}
	
	/**
	* Sets the color transform for a Color object to its default values.
	* 
	* @param	col		The Color object to manipulate.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* my_color.setRGB(0x0000FF);
	* ColorUtil.reset(my_color);
	* </code></pre>
	*/
	public static function reset (col:Color):Void {
		col.setTransform({ra:100, ga:100, ba:100, rb:0, gb:0, bb:0});
	}
	
	/**
	* Specifies the brightness of a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	bright	A percentage value between -100 and 100. Positive values brighten the color. and negative values darken it.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBrightness(my_color, 50);
	* </code></pre>
	*/
	public static function setBrightness (col:Color, bright:Number):Void {
		var trans:Object = col.getTransform();
		with (trans) {
			ra = ga = ba = 100 - Math.abs(bright);
			rb = gb = bb = (bright > 0) ? bright * (256/100) : 0;
		}
		col.setTransform(trans);
	}
	
	/**
	* Returns the brightness of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The brightness value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBrightness(my_color, 50);
	* trace (ColorUtil.getBrightness(my_color));
	* </code></pre>
	*/
	public static function getBrightness (col:Color):Number {
		var trans:Object = col.getTransform();
		with (trans) return rb ? 100 - ra : ra - 100;
	}
	
	/**
	* Pushes a Color object towards black or white by an absolute amount.
	* 
	* @param	col		The Color object to manipulate.
	* @param	offset	A number between -255 and 255. Positive values push colors towards white; negative values towards black.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBrightOffset(my_color, 140);
	* </code></pre>
	*/
	public static function setBrightOffset (col:Color, offset:Number):Void {
		var trans:Object = col.getTransform();
		with (trans) rb = gb = bb = offset;
		col.setTransform(trans);
	}
	
	/**
	* Returns the brightness offset value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The brightness offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBrightOffset(my_color, 140);
	* trace (ColorUtil.getBrightOffset(my_color));
	* </code></pre>
	*/
	public static function getBrightOffset (col:Color):Number {
		return col.getTransform().rb;
	}
	
	/**
	* Tints a color object with a Color according to a certain percentage.
	* 
	* @param	col		The Color object to manipulate.
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTint(my_color, 0, 0, 128, 50);
	* </code></pre>
	*/
	public static function setTint (col:Color, r:Number, g:Number, b:Number, percent:Number):Void {
		var ratio:Number = percent/100;
		var trans:Object = {rb:r*ratio, gb:g*ratio, bb:b*ratio};
		trans.ra = trans.ga = trans.ba = 100 - percent;
		col.setTransform(trans);
	}
	
	/**
	* Returns the tint of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The tint value object with r, g, b, and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTint(my_color, 0, 0, 128, 50);
	* var tint:Object = ColorUtil.getTint(my_color);
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* trace (tint.percent);
	* </code></pre>
	*/
	public static function getTint (col:Color):Object {
		var trans:Object = col.getTransform();
		var tint:Object = {percent: 100 - trans.ra};
		var ratio:Number = 100/tint.percent;
		tint.r = trans.rb * ratio;
		tint.g = trans.gb * ratio;
		tint.b = trans.bb * ratio;
		return tint;
	}
	
	/**
	* Tints a color object with a Color according to a certain percentage.
	* 
	* @param	col		The Color object to manipulate.
	* @param	rgb		The rgb value.
	* @param	percent	The tint percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTint2(my_color, 0x0000FF, 100);
	* </code></pre>
	*/
	public static function setTint2 (col:Color, rgb:Number, percent:Number):Void {
		var r:Number = (rgb >> 16);
		var g:Number = (rgb >> 8) & 0xFF;
		var b:Number = rgb & 0xFF;
		var ratio:Number = percent/100;
		var trans:Object = {rb:r*ratio, gb:g*ratio, bb:b*ratio};
		trans.ra = trans.ga = trans.ba = 100 - percent;
		col.setTransform (trans);
	}
	
	/**
	* Returns the tint of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The tint value object with rgb and percent properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTint2(my_color, 0x0000FF, 100);
	* var tint:Object = ColorUtil.getTint2(my_color);
	* trace (tint.rgb);
	* trace (tint.percent);
	* </code></pre>
	*/
	public static function getTint2 (col:Color):Object {
		var trans:Object = col.getTransform();
		var tint:Object = {percent: 100 - trans.ra};
		var ratio:Number = 100/tint.percent;
		tint.rgb = (trans.rb*ratio)<<16 | (trans.gb*ratio)<<8 | trans.bb*ratio;
		return tint;
	}
	
	/**
	* Tints a Color object with a color according to red, green, and blue values.
	* 
	* @param	col		The Color object to manipulate.
	* @param	r		The red color value.
	* @param	g		The green color value.
	* @param	b		The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTintOffset(my_color, 0, 0, 128);
	* </code></pre>
	*/
	public static function setTintOffset (col:Color, r:Number, g:Number, b:Number):Void {
		var trans:Object = col.getTransform();
		with (trans) { rb=r; gb=g; bb=b; }
		col.setTransform (trans);
	}
	
	/**
	* Returns the tint offset of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The tint offset value object with r, g, and b properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTintOffset(my_color, 0, 0, 128);
	* var tint:Object = ColorUtil.getTintOffset(my_color);
	* trace (tint.r);
	* trace (tint.g);
	* trace (tint.b);
	* </code></pre>
	*/
	public static function getTintOffset (col:Color):Object {
		var t:Object = col.getTransform();
		return {r:t.rb, g:t.gb, b:t.bb};
	}
	
	/**
	* Tints a Color object with a color according to an rgb value.
	* 
	* @param	col		The Color object to manipulate.
	* @param	rgb		The rgb value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTintOffset2(my_color, 0x000080);
	* </code></pre>
	*/
	public static function setTintOffset2 (col:Color, rgb:Number):Void {
		var r:Number = (rgb >> 16) ;
		var g:Number = (rgb >> 8) & 0xFF;
		var b:Number = rgb & 0xFF;
		var trans:Object = col.getTransform();
		with (trans) { rb=r; gb=g; bb=b; }
		col.setTransform (trans);
	}
	
	/**
	* Returns the tint offset of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The tint offset value object with an rgb properties.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setTintOffset2(my_color, 0x000080);
	* trace (ColorUtil.getTintOffset2(my_color));
	* </code></pre>
	*/
	public static function getTintOffset2 (col:Color):Number {
		var t:Object = col.getTransform();
		return (t.rb)<<16 | (t.gb)<<8 | (t.bb);
	}
	
	/**
	* Performs a straightforward color inversion.
	* 
	* @param	col		The Color object to manipulate.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.invert(my_color);
	* </code></pre>
	*/
	public static function invert (col:Color):Void {
		var trans:Object = col.getTransform();
		with (trans) {
			ra = -ra;
			ga = -ga;
			ba = -ba;
			rb = 255 - rb;
			gb = 255 - gb;
			bb = 255 - bb;
		}
		col.setTransform (trans);
	}
	
	/**
	* Inverts a Color object by a certain percentage.
	* 
	* @param	col		The Color object to manipulate.
	* @param	percent	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setNegative(my_color, 60);
	* </code></pre>
	*/
	public static function setNegative (col:Color, percent:Number):Void {
		var t:Object = {};
		t.ra = t.ga = t.ba = 100 - 2 * percent;
		t.rb = t.gb = t.bb = percent * (255/100);
		col.setTransform (t);
	}
	
	/**
	* Returns the negative percentage of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The negative percentage.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setNegative(my_color, 60);
	* trace (ColorUtil.getNegative(my_color));
	* </code></pre>
	*/
	public static function getNegative (col:Color):Number {
		return col.getTransform().rb * (100/255);
	}
	
	/**
	* Specifies a red color value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	amount	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRed(my_color, 128);
	* </code></pre>
	*/
	public static function setRed (col:Color, amount:Number):Void {
		var t:Object = col.getTransform();
		col.setRGB (amount << 16 | t.gb << 8 | t.bb);
	}
	
	/**
	* Returns the red color value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The red color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRed(my_color, 128);
	* trace (ColorUtil.getRed(my_color));
	* </code></pre>
	*/
	public static function getRed (col:Color):Number {
		return col.getTransform().rb;
	}
	
	/**
	* Specifies a green color value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	amount	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setGreen(my_color, 128);
	* </code></pre>
	*/
	public static function setGreen (col:Color, amount:Number):Void {
		var t:Object = col.getTransform();
		col.setRGB (t.rb << 16 | amount << 8 | t.bb);
	}
	
	/**
	* Returns the green color value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The green color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setGreen(my_color, 128);
	* trace (ColorUtil.getGreen(my_color));
	* </code></pre>
	*/
	public static function getGreen (col:Color):Number {
		return col.getTransform().gb;
	}
	
	/**
	* Specifies a blue color value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	amount	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBlue(my_color, 128);
	* </code></pre>
	*/
	public static function setBlue (col:Color, amount:Number):Void {
		var t:Object = col.getTransform();
		col.setRGB (t.rb << 16 | t.gb << 8 | amount);
	}
	
	/**
	* Returns the blue color value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The blue color value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBlue(my_color, 128);
	* trace (ColorUtil.getBlue(my_color));
	* </code></pre>
	*/
	public static function getBlue (col:Color):Number {
		return col.getTransform().bb;
	}
	
	/**
	* Specifies a red percentage value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	percent	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRedPercent(my_color, 50);
	* </code></pre>
	*/
	public static function setRedPercent (col:Color, percent:Number):Void {
		var trans:Object = col.getTransform();
		trans.ra = percent;
		col.setTransform (trans);
	}
	
	/**
	* Returns the red percentage value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The red percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRedPercent(my_color, 50);
	* trace (ColorUtil.getRedPercent(my_color));
	* </code></pre>
	*/
	public static function getRedPercent (col:Color):Number {
		return col.getTransform().ra;
	}
	
	/**
	* Specifies a green percentage value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	percent	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setGreenPercent(my_color, 50);
	* </code></pre>
	*/
	public static function setGreenPercent (col:Color, percent:Number):Void {
		var trans:Object = col.getTransform();
		trans.ga = percent;
		col.setTransform (trans);
	}
	
	/**
	* Returns the green percentage value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The green percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setGreenPercent(my_color, 50);
	* trace (ColorUtil.getGreenPercent(my_color));
	* </code></pre>
	*/
	public static function getGreenPercent (col:Color):Number {
		return col.getTransform().ga;
	}
	
	/**
	* Specifies a blue percentage value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	percent	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBluePercent(my_color, 50);
	* </code></pre>
	*/
	public static function setBluePercent (col:Color, percent:Number):Void {
		var trans:Object = col.getTransform();
		trans.ba = percent;
		col.setTransform (trans);
	}
	
	/**
	* Returns the blue percentage value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The blue percentage value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBluePercent(my_color, 50);
	* trace (ColorUtil.getBluePercent(my_color));
	* </code></pre>
	*/
	public static function getBluePercent (col:Color):Number {
		return col.getTransform().ba;
	}
	
	/**
	* Specifies a red offset value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	percent	The red offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRedOffset(my_color, -128);
	* </code></pre>
	*/
	public static function setRedOffset (col:Color, offset:Number):Void {
		var trans:Object = col.getTransform();
		trans.rb = offset;
		col.setTransform (trans);
	}
	
	/**
	* Returns the red offset value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The red offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setRedOffset(my_color, -128);
	* trace (ColorUtil.getRedOffset(my_color));
	* </code></pre>
	*/
	public static function getRedOffset (col:Color):Number {
		return col.getTransform().rb;
	}
	
	/**
	* Specifies a green offset value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	percent	The green offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setGreenOffset(my_color, -128);
	* </code></pre>
	*/
	public static function setGreenOffset (col:Color, offset:Number):Void {
		var trans:Object = col.getTransform();
		trans.gb = offset;
		col.setTransform (trans);
	}
	
	/**
	* Returns the green offset value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The green offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setGreenOffset(my_color, -128);
	* trace (ColorUtil.getGreenOffset(my_color));
	* </code></pre>
	*/
	public static function getGreenOffset (col:Color):Number {
		return col.getTransform().gb;
	}
	
	/**
	* Specifies a blue offset value for a Color object.
	* 
	* @param	col		The Color object to manipulate.
	* @param	percent	The blue offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBlueOffset(my_color, -128);
	* </code></pre>
	*/
	public static function setBlueOffset (col:Color, offset:Number):Void {
		var trans:Object = col.getTransform();
		trans.bb = offset;
		col.setTransform (trans);
	}
	
	/**
	* Returns the blue offset value of a Color object.
	* 
	* @param	col		The Color object from which to retrieve the value.
	* @return	The blue offset value.
	* 
	* @usage
	* <pre><code>
	* var my_color:Color = new Color(my_mc);
	* ColorUtil.setBlueOffset(my_color, -128);
	* trace (ColorUtil.getBlueOffset(my_color));
	* </code></pre>
	*/
	public static function getBlueOffset (col:Color):Number {
		return col.getTransform().bb;
	}
	
}
